]> git.sesse.net Git - movit/blobdiff - util.h
Some microoptimizations in combine_two_samples(). Saves about 4% in ResampleEffect...
[movit] / util.h
diff --git a/util.h b/util.h
index f5b5dd368f4665c25d2e3c438714c2696cf90234..577140b50f3ba7a05796a61f27a6683606c6b227 100644 (file)
--- a/util.h
+++ b/util.h
@@ -8,6 +8,7 @@
 #include <stdlib.h>
 #include <Eigen/Core>
 #include <string>
+#include "defs.h"
 
 #define BUFFER_OFFSET(i) ((char *)NULL + (i))
 
@@ -58,7 +59,8 @@ enum CombineRoundingBehavior {
 // number of distinct accessible subtexels in the given mipmap level,
 // calculated by num_texels / movit_texel_subpixel_precision. It is a float
 // for performance reasons, even though it is expected to be a whole number.
// <inv_num_subtexels> is simply its inverse (1/x).
 //
 // Note that since the GPU might have limited precision in its linear
 // interpolation, the effective weights might be different from the ones you
@@ -71,7 +73,7 @@ enum CombineRoundingBehavior {
 // rounded fp16 value. This enables more precise calculation of total_weight
 // and sum_sq_error.
 template<class DestFloat>
-void combine_two_samples(float w1, float w2, float pos1, float pos2, float num_subtexels, float inv_num_subtexels,
+void combine_two_samples(float w1, float w2, float pos1, float pos1_pos2_diff, float inv_pos1_pos2_diff, float num_subtexels, float inv_num_subtexels,
                          DestFloat *offset, DestFloat *total_weight, float *sum_sq_error);
 
 // Create a VBO with the given data. Returns the VBO number.
@@ -93,12 +95,15 @@ unsigned next_power_of_two(unsigned v);
 // back into anything you intend to pass into OpenGL.
 void *get_gl_context_identifier();
 
+// Used in the check_error() macro, below.
+void abort_gl_error(GLenum err, const char *filename, int line) DOES_NOT_RETURN;
+
 }  // namespace movit
 
 #ifdef NDEBUG
 #define check_error()
 #else
-#define check_error() { int err = glGetError(); if (err != GL_NO_ERROR) { printf("GL error 0x%x at %s:%d\n", err, __FILE__, __LINE__); abort(); } }
+#define check_error() { GLenum err = glGetError(); if (err != GL_NO_ERROR) { movit::abort_gl_error(err, __FILE__, __LINE__); } }
 #endif
 
 // CHECK() is like assert(), but retains any side effects no matter the compilation mode.
@@ -58,7 +59,8 @@ enum CombineRoundingBehavior {
 // calculated by num_texels / movit_texel_subpixel_precision. It is a float
 // for performance reasons, even though it is expected to be a whole number.
-// <inv_num_subtexels> is simply its inverse (1/x).
+// <inv_num_subtexels> is simply its inverse (1/x). <pos1_pos2_diff> is
+// (pos2-pos1) and <inv_pos1_pos2_diff> is 1/(pos2-pos1).
 //
 // Note that since the GPU might have limited precision in its linear